@@ -11,7 +11,7 @@ from astrape.exceptions.exceptions import *
 from astrape.model_selection import CrossValidation
 from astrape.constants.astrape_constants import *
 
-from typing import Union, List, Dict, Any, Optional, cast, overload
+from typing import Union, List, Dict, Any, Optional, Tuple, cast, overload
 
 import warnings
 warnings.filterwarnings(action='ignore')
@@ -60,7 +60,7 @@ class Experiment(BaseExperiment):
         n_random_search : Optional[int] = None,
         cv : int = 5,
         random_number : int = DEFAULT_RANDOM_SEED_NUMBER 
-    )->tuple[Union["pl.LightningModule", "BaseEstimator"],dict]:
+    )->Tuple[Union["pl.LightningModule", "BaseEstimator"],Dict]:
         self.fit_or_cv = "CV"
         self.update_log_path()
         best_model_structure, info = CrossValidation(
