@@ -1,5 +1,5 @@
 import pytorch_lightning as pl 
-from typing import Union, List, Dict, Any, Optional, cast
+from typing import Union, List, Dict, Any, Optional, Tuple, cast
 from astrape.utilities.dataloader_lightning import *
 import inspect
 from astrape.constants.astrape_constants import *
@@ -27,7 +27,7 @@ def initialize_model(
     model_type : "pl.LightningModule", 
     dims : int, 
     n_classes : int, 
-    **config : dict
+    **config : Dict
 )->Union["pl.LightningModule", "BaseEstimator"]:
     r"""Initializes Lightning model.
     """
@@ -40,7 +40,7 @@ def initialize_model(
     
 def initialize_datamodule(
     **config
-)->Union["pl.LightningDataModule", tuple]:
+)->Union["pl.LightningDataModule", Tuple]:
     r"""
 
     Args:
